"use strict";
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
var VLCRCModifier_1 = require("../../src/util/VLCRCModifier");
var path = __importStar(require("path"));
var fs = __importStar(require("fs"));
describe('vlcrc', function () {
    it('_getPath', function () {
        var x = VLCRCModifier_1._getPath();
        expect(x).toBeDefined();
    });
    describe('_readLine', function () {
        describe('enabled', function () {
            it('defined', function () {
                var example = 'http-password=Qwerty';
                var parsed = VLCRCModifier_1._readLine(example);
                if (parsed == undefined)
                    fail('Failed to parse example ' + example);
                else {
                    expect(parsed.key).toBe('http-password');
                    expect(parsed.value).toBe('Qwerty');
                    expect(parsed.enabled).toBe(true);
                }
            });
            it('undefined', function () {
                var example = 'Test';
                var parsed = VLCRCModifier_1._readLine(example);
                expect(parsed).toBeUndefined();
            });
        });
        describe('disabled', function () {
            it('defined', function () {
                var example = '#http-password=Qwerty';
                var parsed = VLCRCModifier_1._readLine(example);
                if (parsed == undefined)
                    fail('Failed to parse example ' + example);
                else {
                    expect(parsed.key).toBe('http-password');
                    expect(parsed.value).toBe('Qwerty');
                    expect(parsed.enabled).toBe(false);
                }
            });
            it('undefined', function () {
                var example = '#Test';
                var parsed = VLCRCModifier_1._readLine(example);
                expect(parsed).toBeUndefined();
            });
        });
    });
    describe('VLCRCModifier', function () {
        var resolved = path.resolve(__dirname + "/vlcrc");
        var modifier = VLCRCModifier_1.editVLCRC(resolved);
        var data = fs.readFileSync(resolved);
        beforeEach(function () {
            modifier = VLCRCModifier_1.editVLCRC(resolved);
        });
        it('export', function () {
            var exported = modifier.export();
            expect(exported.toString()).toContain(data.toString());
        });
        it('get', function () {
            var get = modifier.get('http-password');
            if (get) {
                expect(get.key).toBe('http-password');
                expect(get.value).toBe('Qwerty');
                expect(get.enabled).toBe(true);
            }
            else
                fail('Failed tp get http-password');
        });
        it('set', function () {
            var set = modifier.set('http-password', 'qWerty');
            if (set) {
                expect(set.key).toBe('http-password');
                expect(set.value).toBe('qWerty');
                expect(set.enabled).toBe(true);
            }
            else
                fail('Failed to get http-password key while setting');
        });
        it('disable', function () {
            var disabled = modifier.disable('http-password');
            if (disabled) {
                expect(disabled.enabled).toBe(false);
                expect(disabled.key).toBe('http-password');
                expect(disabled.value).toBe('Qwerty');
            }
            else
                fail('Failed to disable http-password');
        });
        it('enable', function () {
            var enabled = modifier.enable('http-password');
            if (enabled) {
                expect(enabled.enabled).toBe(true);
                expect(enabled.key).toBe('http-password');
                expect(enabled.value).toBe('Qwerty');
            }
            else
                fail('Failed to enable http-password');
        });
    });
});
