import {VLCClient} from "../../src";
import {VLCStatus} from "../../src/http/classes/VLCStatus";
import {VLCPlaylist} from "../../src/http/classes/VLCPlaylist";

const client: VLCClient = new VLCClient({
    address: '127.0.0.1',
    password: 'rosebud',
    port: 8080
});

describe('Client', function () {

    it('getStatus', async function () {
        const status = await client.getStatus();
        expect(status).toBeInstanceOf(VLCStatus);
    });

    it('getPlaylist', async () => {
        const playlist = await client.getPlaylist();
        expect(playlist).toBeInstanceOf(VLCPlaylist)
    });

    it('add', async () => {
        await client.add(encodeURI('http://ytcracker.com/music/categoryFive - kilobyte.mp3'), true);
        const status = await client.getStatus();
        if (status.information != undefined) {
            expect(status.information.category.meta.filename).toBe('categoryFive - kilobyte.mp3');
        }
    }, 5000);

    it('empty', async () => {
        await client.empty();
        const status = await client.getStatus();
        expect(status.information).toBe(undefined)
    }, 5000);

    it('fullscreen', async () => {
        await client.add('mrl', true);
        setTimeout(async () => {
            await client.fullscreen(true);
            const status = await client.getStatus();
            expect(status.fullscreen).toBe(true)
        }, 5000);
    });

    it('loop', async () => {
        await client.loop(true);
        const status = await client.getStatus();
        expect(status.loop).toBe(true)
    });

    it('repeat', async () => {
        await client.repeat(true);
        const status = await client.getStatus();
        expect(status.repeat).toBe(true)
    });

    it('random', async () => {
        await client.random(true);
        const status = await client.getStatus();
        expect(status.random).toBe(true);
    });

    it('volume', async () => {
        await client.volume(90);
        const status = await client.getStatus();
        expect(status.volume).toBe(90)
    })
});
