import {_getPath, _readLine, editVLCRC} from '../../src/util/VLCRCModifier'
import * as path from "path";
import * as fs from "fs";

describe('vlcrc', function () {
    it('_getPath', () => {
        const x = _getPath();
        expect(x).toBeDefined();
    });
    describe('_readLine', () => {
        describe('enabled', function () {
            it('defined', () => {
                const example = 'http-password=Qwerty';
                const parsed = _readLine(example);
                if (parsed == undefined) fail('Failed to parse example ' + example);
                else {
                    expect(parsed.key).toBe('http-password');
                    expect(parsed.value).toBe('Qwerty');
                    expect(parsed.enabled).toBe(true)
                }

            });
            it('undefined', () => {
                const example = 'Test';
                const parsed = _readLine(example);
                expect(parsed).toBeUndefined();
            });
        });
        describe('disabled', function () {
            it('defined', () => {
                const example = '#http-password=Qwerty';
                const parsed = _readLine(example);
                if (parsed == undefined) fail('Failed to parse example ' + example);
                else {
                    expect(parsed.key).toBe('http-password');
                    expect(parsed.value).toBe('Qwerty');
                    expect(parsed.enabled).toBe(false)
                }

            });
            it('undefined', () => {
                const example = '#Test';
                const parsed = _readLine(example);
                expect(parsed).toBeUndefined();
            })
        });
    });

    describe('VLCRCModifier', function () {
        const resolved = path.resolve(`${__dirname}/vlcrc`);
        let modifier = editVLCRC(resolved);
        const data = fs.readFileSync(resolved);

        beforeEach(() => {
            modifier = editVLCRC(resolved)
        });

        it('export', () => {
            const exported = modifier.export();
            expect(exported.toString()).toContain(data.toString());
        });

        it('get', () => {
            const get = modifier.get('http-password');
            if (get) {
                expect(get.key).toBe('http-password');
                expect(get.value).toBe('Qwerty');
                expect(get.enabled).toBe(true);
            } else fail('Failed tp get http-password')
        });

        it('set', () => {
            const set = modifier.set('http-password', 'qWerty');
            if (set) {
                expect(set.key).toBe('http-password');
                expect(set.value).toBe('qWerty');
                expect(set.enabled).toBe(true);
            } else fail('Failed to get http-password key while setting');
        });

        it('disable', () => {
            const disabled = modifier.disable('http-password');
            if (disabled) {
                expect(disabled.enabled).toBe(false);
                expect(disabled.key).toBe('http-password');
                expect(disabled.value).toBe('Qwerty')
            } else fail('Failed to disable http-password');
        });

        it('enable', () => {
            const enabled = modifier.enable('http-password');
            if (enabled) {
                expect(enabled.enabled).toBe(true);
                expect(enabled.key).toBe('http-password');
                expect(enabled.value).toBe('Qwerty')
            } else fail('Failed to enable http-password');
        });
    });
});